// generated from rosidl_adapter/resource/msg.idl.em
// with input from lifecycle_msgs/msg/TransitionEvent.msg
// generated code does not contain a copyright notice

#include "lifecycle_msgs/msg/State.idl"
#include "lifecycle_msgs/msg/Transition.idl"

module lifecycle_msgs {
  module msg {
    @verbatim (language="comment", text=
      "The time point at which this event occurred.")
    struct TransitionEvent {
      uint64 timestamp;

      @verbatim (language="comment", text=
        "The id and label of this transition event.")
      lifecycle_msgs::msg::Transition transition;

      @verbatim (language="comment", text=
        "The starting state from which this event transitioned.")
      lifecycle_msgs::msg::State start_state;

      @verbatim (language="comment", text=
        "The end state of this transition event.")
      lifecycle_msgs::msg::State goal_state;
    };
  };
};
