// generated from rosidl_generator_c/resource/idl.h.em
// with input from lifecycle_msgs:msg/Transition.idl
// generated code does not contain a copyright notice

#ifndef LIFECYCLE_MSGS__MSG__TRANSITION_H_
#define LIFECYCLE_MSGS__MSG__TRANSITION_H_

#include "lifecycle_msgs/msg/detail/transition__struct.h"
#include "lifecycle_msgs/msg/detail/transition__functions.h"
#include "lifecycle_msgs/msg/detail/transition__type_support.h"

#endif  // LIFECYCLE_MSGS__MSG__TRANSITION_H_
