// generated from rosidl_adapter/resource/msg.idl.em
// with input from lifecycle_msgs/msg/Transition.msg
// generated code does not contain a copyright notice


module lifecycle_msgs {
  module msg {
    module Transition_Constants {
      @verbatim (language="comment", text=
        "Reserved, publicly available transitions." "\n"        "When a node is in one of these primary states, these transitions can be" "\n"        "invoked." "\n"        "This transition will instantiate the node, but will not run any code beyond" "\n"        "the constructor.")
      const uint8 TRANSITION_CREATE = 0;
      @verbatim (language="comment", text=
        "The node’s onConfigure callback will be called to allow the node to load its" "\n"        "configuration and conduct any required setup.")
      const uint8 TRANSITION_CONFIGURE = 1;
      @verbatim (language="comment", text=
        "The node’s callback onCleanup will be called in this transition to allow the" "\n"        "node to load its configuration and conduct any required setup.")
      const uint8 TRANSITION_CLEANUP = 2;
      @verbatim (language="comment", text=
        "The node's callback onActivate will be executed to do any final preparations" "\n"        "to start executing.")
      const uint8 TRANSITION_ACTIVATE = 3;
      @verbatim (language="comment", text=
        "The node's callback onDeactivate will be executed to do any cleanup to start" "\n"        "executing, and reverse the onActivate changes.")
      const uint8 TRANSITION_DEACTIVATE = 4;
      @verbatim (language="comment", text=
        "This signals shutdown during an unconfigured state, the node's callback" "\n"        "onShutdown will be executed to do any cleanup necessary before destruction.")
      const uint8 TRANSITION_UNCONFIGURED_SHUTDOWN = 5;
      @verbatim (language="comment", text=
        "This signals shutdown during an inactive state, the node's callback onShutdown" "\n"        "will be executed to do any cleanup necessary before destruction.")
      const uint8 TRANSITION_INACTIVE_SHUTDOWN = 6;
      @verbatim (language="comment", text=
        "This signals shutdown during an active state, the node's callback onShutdown" "\n"        "will be executed to do any cleanup necessary before destruction.")
      const uint8 TRANSITION_ACTIVE_SHUTDOWN = 7;
      @verbatim (language="comment", text=
        "This transition will simply cause the deallocation of the node.")
      const uint8 TRANSITION_DESTROY = 8;
      @verbatim (language="comment", text=
        "Reserved, private transitions" "\n"        "These transitions are not publicly available and cannot be invoked by a user." "\n"        "The following transitions are implicitly invoked based on the callback" "\n"        "feedback of the intermediate transition states.")
      const uint8 TRANSITION_ON_CONFIGURE_SUCCESS = 10;
      const uint8 TRANSITION_ON_CONFIGURE_FAILURE = 11;
      const uint8 TRANSITION_ON_CONFIGURE_ERROR = 12;
      const uint8 TRANSITION_ON_CLEANUP_SUCCESS = 20;
      const uint8 TRANSITION_ON_CLEANUP_FAILURE = 21;
      const uint8 TRANSITION_ON_CLEANUP_ERROR = 22;
      const uint8 TRANSITION_ON_ACTIVATE_SUCCESS = 30;
      const uint8 TRANSITION_ON_ACTIVATE_FAILURE = 31;
      const uint8 TRANSITION_ON_ACTIVATE_ERROR = 32;
      const uint8 TRANSITION_ON_DEACTIVATE_SUCCESS = 40;
      const uint8 TRANSITION_ON_DEACTIVATE_FAILURE = 41;
      const uint8 TRANSITION_ON_DEACTIVATE_ERROR = 42;
      const uint8 TRANSITION_ON_SHUTDOWN_SUCCESS = 50;
      const uint8 TRANSITION_ON_SHUTDOWN_FAILURE = 51;
      const uint8 TRANSITION_ON_SHUTDOWN_ERROR = 52;
      const uint8 TRANSITION_ON_ERROR_SUCCESS = 60;
      const uint8 TRANSITION_ON_ERROR_FAILURE = 61;
      const uint8 TRANSITION_ON_ERROR_ERROR = 62;
      @verbatim (language="comment", text=
        "Reserved. Transition callback success values." "\n"        "These return values ought to be set as a return value for each callback." "\n"        "Depending on which return value, the transition will be executed correctly or" "\n"        "fallback/error callbacks will be triggered." "\n"        "The transition callback successfully performed its required functionality.")
      const uint8 TRANSITION_CALLBACK_SUCCESS = 97;
      @verbatim (language="comment", text=
        "The transition callback failed to perform its required functionality.")
      const uint8 TRANSITION_CALLBACK_FAILURE = 98;
      @verbatim (language="comment", text=
        "The transition callback encountered an error that requires special cleanup, if" "\n"        "possible.")
      const uint8 TRANSITION_CALLBACK_ERROR = 99;
    };
    @verbatim (language="comment", text=
      "Default values for transitions as described in:" "\n"
      "http://design.ros2.org/articles/node_lifecycle.html")
    struct Transition {
      @verbatim (language="comment", text=
        "Fields" "\n"
        "" "\n"
        "The transition id from above definitions.")
      uint8 id;

      @verbatim (language="comment", text=
        "A text label of the transition.")
      string label;
    };
  };
};
