// generated from rosidl_adapter/resource/srv.idl.em
// with input from lifecycle_msgs/srv/GetState.srv
// generated code does not contain a copyright notice

#include "lifecycle_msgs/msg/State.idl"

module lifecycle_msgs {
  module srv {
    struct GetState_Request {
      uint8 structure_needs_at_least_one_member;
    };
    @verbatim (language="comment", text=
      "The current state-machine state of the node.")
    struct GetState_Response {
      lifecycle_msgs::msg::State current_state;
    };
  };
};
