// generated from rosidl_adapter/resource/msg.idl.em
// with input from lifecycle_msgs/msg/TransitionDescription.msg
// generated code does not contain a copyright notice

#include "lifecycle_msgs/msg/State.idl"
#include "lifecycle_msgs/msg/Transition.idl"

module lifecycle_msgs {
  module msg {
    @verbatim (language="comment", text=
      "The transition id and label of this description.")
    struct TransitionDescription {
      lifecycle_msgs::msg::Transition transition;

      @verbatim (language="comment", text=
        "The current state from which this transition transitions.")
      lifecycle_msgs::msg::State start_state;

      @verbatim (language="comment", text=
        "The desired target state of this transition.")
      lifecycle_msgs::msg::State goal_state;
    };
  };
};
